pub enum ServerCertVerifierError {
InvalidRootCertificate {
cert: CertificateDer,
reason: String,
},
InvalidEndEntityCertificate {
cert: CertificateDer,
reason: String,
},
InvalidPath,
InvalidServerName,
}Expand description
Error for ServerCertVerifier.
Variants
InvalidRootCertificate
Root certificate store contains invalid certificate.
InvalidEndEntityCertificate
End-entity certificate is invalid.
InvalidPath
Failed to verify certificate path to provided trust anchors.
InvalidServerName
Failed to verify certificate is valid for provided server name.