pub struct RootCertStore {
pub roots: Vec<CertificateDer>,
}Expand description
Root certificate store.
This stores root certificates which are used to verify end-entity certificates presented by a TLS server.
Fields
roots: Vec<CertificateDer>Unvalidated DER-encoded X.509 root certificates.
Implementations
Sourceimpl RootCertStore
impl RootCertStore
Sourcepub fn empty() -> RootCertStore
pub fn empty() -> RootCertStore
Creates an empty root certificate store.
Sourcepub fn mozilla() -> RootCertStore
pub fn mozilla() -> RootCertStore
Creates a root certificate store with Mozilla root certificates.
These certificates are sourced from webpki-root-certs. It is not recommended to use these unless the
application binary can be recompiled and deployed on-demand in the case
that the root certificates need to be updated.